This is an automated email from the ASF dual-hosted git repository.

alexstocks pushed a commit to branch develop
in repository https://gitbox.apache.org/repos/asf/dubbo-go.git


The following commit(s) were added to refs/heads/develop by this push:
     new 1f05305ee fix: polaris router support application name (#3164)
1f05305ee is described below

commit 1f05305eeb0269c8f174b92cfdda082e13a65412
Author: zbchi <[email protected]>
AuthorDate: Sun Jan 18 22:20:03 2026 +0800

    fix: polaris router support application name (#3164)
    
    * fix: polaris router support application name
---
 cluster/router/polaris/router.go | 8 +++++---
 1 file changed, 5 insertions(+), 3 deletions(-)

diff --git a/cluster/router/polaris/router.go b/cluster/router/polaris/router.go
index 98f41966e..8abe78cf6 100644
--- a/cluster/router/polaris/router.go
+++ b/cluster/router/polaris/router.go
@@ -53,11 +53,13 @@ var (
 
 func newPolarisRouter(url *common.URL) (*polarisRouter, error) {
 
        // get from url param
        applicationName := url.GetParam(constant.ApplicationKey, "")
-
        if applicationName == "" {
-               return nil, fmt.Errorf("polaris router must set application 
name")
+               applicationName = url.SubURL.GetParam(constant.ApplicationKey, 
"")
+               if applicationName == "" {
+                       return nil, fmt.Errorf("polaris router must set 
application name")
+               }
        }
 
        // get from url attr
@@ -53,11 +53,13 @@ var (
 func newPolarisRouter(url *common.URL) (*polarisRouter, error) {
 
-       // get from url param
+       // get application name from url param
        applicationName := url.GetParam(constant.ApplicationKey, "")

Reply via email to